@@ -33,7 +33,6 @@
 #include <glib/gstdio.h>
 
 #include <libedataserver/e-data-server-util.h>
-#include <libedataserver/e-memory.h>
 #include <libedataserver/e-msgport.h>
 
 #include "camel-file-utils.h"
@@ -142,8 +141,8 @@ static GMutex *ref_lock;
 static GHashTable *type_table;
 
 /* fundamental types are accessed via global */
-CamelType camel_object_type;
-CamelType camel_interface_type;
+CamelType camel_object_type = CAMEL_INVALID_TYPE;
+CamelType camel_interface_type = CAMEL_INVALID_TYPE;
 
 #define P_LOCK(l) (pthread_mutex_lock(&l))
 #define P_UNLOCK(l) (pthread_mutex_unlock(&l))
