@@ -120,7 +120,7 @@ camel_vee_folder_construct (CamelVeeFolder *vf, CamelStore *parent_store, const
  * camel_vee_folder_new:
  * @parent_store: the parent CamelVeeStore
  * @full: the full path to the vfolder.
- * @ex: a CamelException
+ * @flags: flags of some kind
  *
  * Create a new CamelVeeFolder object.
  *
@@ -471,10 +471,10 @@ summary_header_to_db (CamelFolderSummary *s, CamelException *ex)
 {
 	CamelFIRecord * record = g_new0 (CamelFIRecord, 1);
 	CamelDB *db;
+	char *table_name;
 
 	db = s->folder->parent_store->cdb;
-	char *table_name = s->folder->full_name;
-
+	table_name = s->folder->full_name;
 
 	record->folder_name = table_name;
 
@@ -671,7 +671,7 @@ vee_search_by_expression(CamelFolder *folder, const char *expression, CamelExcep
 
 
 	g_hash_table_destroy(searched);
-	printf("returning %d\n", result->len);
+	d(printf("returning %d\n", result->len));
 	return result;
 }
 
@@ -881,7 +881,7 @@ vee_folder_remove_folder(CamelVeeFolder *vf, CamelFolder *source)
 							if (n == 1) {
 								CamelMessageInfo *tinfo;
 								g_hash_table_remove(unmatched_uids, oldkey);
-								if (tinfo = (CamelMessageInfo *) vee_folder_add_uid(folder_unmatched, source, oldkey+8, hash)) {
+								if ((tinfo = (CamelMessageInfo *) vee_folder_add_uid(folder_unmatched, source, oldkey+8, hash)) != NULL) {
 									camel_message_info_free (tinfo);
 									camel_folder_change_info_add_uid(folder_unmatched->changes, oldkey);
 								}
@@ -1024,7 +1024,7 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 				return -1;
 			rebuilded = TRUE;
 		}
-		printf("len = %d %d\n", match->len, rebuilded);
+		d(printf("len = %d %d\n", match->len, rebuilded));
 	}
 
 	u.source = source;
