@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000 Ximian Inc.
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -30,7 +30,10 @@
 #include <sys/stat.h>
 
 #include "camel-folder.h"
+#include "camel-store.h"
 #include "camel-vee-summary.h"
+#include "camel-private.h"
+#include "camel-string-utils.h"
 
 #define d(x)
 
@@ -41,8 +44,8 @@ vee_message_info_free(CamelFolderSummary *s, CamelMessageInfo *info)
 {
 	CamelVeeMessageInfo *mi = (CamelVeeMessageInfo *)info;
 
-	g_free(info->uid);
-	camel_message_info_free(mi->real);
+	camel_pstring_free(info->uid);
+	camel_object_unref (mi->summary);
 }
 
 static CamelMessageInfo *
@@ -53,40 +56,69 @@ vee_message_info_clone(CamelFolderSummary *s, const CamelMessageInfo *mi)
 
 	to = (CamelVeeMessageInfo *)camel_message_info_new(s);
 
-	to->real = camel_message_info_clone(from->real);
+	to->summary = from->summary;
+	/* FIXME: We may not need this during CamelDBSummary */
+	camel_object_ref (to->summary);
 	to->info.summary = s;
+	to->info.uid = camel_pstring_strdup(from->info.uid);
 
 	return (CamelMessageInfo *)to;
 }
 
 static const void *
-vee_info_ptr(const CamelMessageInfo *mi, int id)
+vee_info_ptr (const CamelMessageInfo *mi, int id)
 {
-	return camel_message_info_ptr(((CamelVeeMessageInfo *)mi)->real, id);
+	CamelVeeMessageInfo *vmi = (CamelVeeMessageInfo *) mi;
+	CamelMessageInfo *info;
+	gpointer p;
+	
+	info = camel_folder_summary_uid (vmi->summary, mi->uid+8);
+	p = (gpointer) camel_message_info_ptr(info, id);
+	camel_message_info_free (info);
+
+	return p;
 }
 
 static guint32
 vee_info_uint32(const CamelMessageInfo *mi, int id)
 {
-	return camel_message_info_uint32(((CamelVeeMessageInfo *)mi)->real, id);
+	CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
+	guint32 ret = camel_message_info_uint32 (rmi, id);
+
+	camel_message_info_free (rmi);
+
+	return ret;
+
 }
 
 static time_t
 vee_info_time(const CamelMessageInfo *mi, int id)
 {
-	return camel_message_info_time(((CamelVeeMessageInfo *)mi)->real, id);
+	CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
+	time_t ret = camel_message_info_time (rmi, id);
+	camel_message_info_free (rmi);
+
+	return ret;
 }
 
 static gboolean
 vee_info_user_flag(const CamelMessageInfo *mi, const char *id)
 {
-	return camel_message_info_user_flag(((CamelVeeMessageInfo *)mi)->real, id);
+	CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
+	gboolean ret = 	camel_message_info_user_flag (rmi, id);
+	camel_message_info_free (rmi);
+
+	return ret;
 }
 
 static const char *
 vee_info_user_tag(const CamelMessageInfo *mi, const char *id)
 {
-	return camel_message_info_user_tag(((CamelVeeMessageInfo *)mi)->real, id);
+	CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
+	const char *ret = camel_message_info_user_tag (rmi, id);
+	camel_message_info_free (rmi);
+
+	return ret;
 }
 
 static gboolean
@@ -94,9 +126,12 @@ vee_info_set_user_flag(CamelMessageInfo *mi, const char *name, gboolean value)
 {
 	int res = FALSE;
 
-	if (mi->uid)
-		res = camel_message_info_set_user_flag(((CamelVeeMessageInfo *)mi)->real, name, value);
-
+	if (mi->uid) {
+		CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
+		res = camel_message_info_set_user_flag(rmi, name, value);
+		camel_message_info_free (rmi);		
+	}
+ 
 	return res;
 }
 
@@ -105,9 +140,12 @@ vee_info_set_user_tag(CamelMessageInfo *mi, const char *name, const char *value)
 {
 	int res = FALSE;
 
-	if (mi->uid)
-		res = camel_message_info_set_user_tag(((CamelVeeMessageInfo *)mi)->real, name, value);
-
+	if (mi->uid) {
+		CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
+		res = camel_message_info_set_user_tag(rmi, name, value);
+		camel_message_info_free (rmi);			
+	}
+ 
 	return res;
 }
 
@@ -116,12 +154,35 @@ vee_info_set_flags(CamelMessageInfo *mi, guint32 flags, guint32 set)
 {
 	int res = FALSE;
 
-	if (mi->uid)
-		res = camel_message_info_set_flags(((CamelVeeMessageInfo *)mi)->real, flags, set);
-
+	if (mi->uid) {
+		CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);		
+		res = camel_message_info_set_flags(rmi, flags, set);
+		camel_message_info_free (rmi);
+	}
+ 
 	return res;
 }
 
+static CamelMessageInfo *
+message_info_from_uid (CamelFolderSummary *s, const char *uid)
+{
+	CamelMessageInfoBase *info;
+
+	#warning "too bad design. Need to peek it from cfs instead of hacking ugly like this"
+	CAMEL_SUMMARY_LOCK(s, summary_lock);
+	CAMEL_SUMMARY_LOCK(s, ref_lock);
+
+	info = g_hash_table_lookup (s->loaded_infos, uid);
+
+	if (info)
+		info->refcount++;
+
+	CAMEL_SUMMARY_UNLOCK(s, ref_lock);
+	CAMEL_SUMMARY_UNLOCK(s, summary_lock);
+
+	return (CamelMessageInfo *) info;	
+}
+
 static void
 camel_vee_summary_class_init (CamelVeeSummaryClass *klass)
 {
@@ -144,6 +205,7 @@ camel_vee_summary_class_init (CamelVeeSummaryClass *klass)
 	((CamelFolderSummaryClass *)klass)->info_set_user_tag = vee_info_set_user_tag;
 
 	((CamelFolderSummaryClass *)klass)->info_set_flags = vee_info_set_flags;
+	((CamelFolderSummaryClass *)klass)->message_info_from_uid = message_info_from_uid;
 }
 
 static void
@@ -193,34 +255,63 @@ camel_vee_summary_new(CamelFolder *parent)
 	s = (CamelVeeSummary *)camel_object_new(camel_vee_summary_get_type());
 	s->summary.folder = parent;
 
+        #warning "fix exceptions and note return values"
+	#warning "if Evo's junk/trash vfolders make it VJunk VTrash instead of .#evolution/Junk-or-whatever"		
+	camel_db_create_vfolder (parent->cdb, parent->full_name, NULL);
+
+	#warning "handle excep and ret"
+	camel_folder_summary_header_load_from_db ((CamelFolderSummary *)s, parent->parent_store, parent->full_name, NULL);	
 	return &s->summary;
 }
 
+GPtrArray *
+camel_vee_summary_get_ids (CamelVeeSummary *summary, char hash[8])
+{
+	char *shash = g_strdup_printf("%c%c%c%c%c%c%c%c", hash[0], hash[1], hash[2], hash[3], hash[4], hash[5], hash[6], hash[7]);
+	CamelFolderSummary *cfs = (CamelFolderSummary *)summary;
+	GPtrArray *array;
+
+	#warning "fix exception passing"
+	array = camel_db_get_vuids_from_vfolder(cfs->folder->cdb, cfs->folder->full_name, shash, NULL);
+	
+	g_free(shash);
+
+	return array;
+}
+
 CamelVeeMessageInfo *
-camel_vee_summary_add(CamelVeeSummary *s, CamelMessageInfo *info, const char hash[8])
+camel_vee_summary_add(CamelVeeSummary *s, CamelFolderSummary *summary, const char *uid, const char hash[8])
 {
 	CamelVeeMessageInfo *mi;
 	char *vuid;
-	const char *uid;
 
-	uid = camel_message_info_uid(info);
 	vuid = g_malloc(strlen(uid)+9);
 	memcpy(vuid, hash, 8);
 	strcpy(vuid+8, uid);
-	mi = (CamelVeeMessageInfo *)camel_folder_summary_uid(&s->summary, vuid);
+	
+	#warning do we need it really ?
+/* 	mi = (CamelVeeMessageInfo *)camel_folder_summary_uid(&s->summary, vuid); */
+/* 	if (mi) { */
+/* 		d(printf("w:clash, we already have '%s' in summary\n", vuid)); */
+/* 		camel_message_info_free((CamelMessageInfo *)mi); */
+/* 		g_free(vuid); */
+/* 		return NULL; */
+/* 	} */
+
+	mi = (CamelVeeMessageInfo *) message_info_from_uid(&s->summary, vuid); 
 	if (mi) {
-		d(printf("w:clash, we already have '%s' in summary\n", vuid));
-		camel_message_info_free((CamelMessageInfo *)mi);
-		g_free(vuid);
-		return NULL;
+		g_warning ("%s - already there\n", vuid);
+		g_free (vuid);
+		return mi;
 	}
 
 	mi = (CamelVeeMessageInfo *)camel_message_info_new(&s->summary);
-	mi->real = info;
-	camel_message_info_ref(info);
-	mi->info.uid = vuid;
-
-	camel_folder_summary_add(&s->summary, (CamelMessageInfo *)mi);
-
+	mi->summary = summary;
+	camel_object_ref (summary);
+	mi->info.uid = (char *) camel_pstring_strdup (vuid);
+	g_free (vuid);
+	camel_message_info_ref (mi);
+	camel_folder_summary_insert(&s->summary, (CamelMessageInfo *)mi, FALSE);
+	
 	return mi;
 }
